@@ -2,9 +2,9 @@
 #'
 #' Return a copy of the string with its first character capitalized and the rest lowercased.
 #'
-#' @param str A string.
+#' @param str A character vector.
 #'
-#' @return A string.
+#' @return A character vector.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.capitalize}
 #'
@@ -15,5 +15,5 @@
 #'
 #' @export
 pystr_capitalize <- function(str) {
-  return(paste0(toupper(substr(str, 1, 1)), tolower(substr(str, 2, nchar(str)))))
+  return(pystr_capitalize_(str))
 }
