@@ -5,11 +5,11 @@
 #' @details Padding is done using the specified \code{fillchar} (default is an ASCII space).
 #' The original string is returned if \code{width} is less than or equal to \code{nchar(str)}.
 #'
-#' @param str A string.
+#' @param str A character vector.
 #' @param width An integer.
-#' @param fillchar A character.
+#' @param fillchar A character string.
 #'
-#' @return A string.
+#' @return A character vector.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.center}
 #'
@@ -21,17 +21,5 @@
 #'
 #' @export
 pystr_center <- function(str, width, fillchar=" ") {
-  if(width <= nchar(str)) {
-    return(str)
-  }
-
-  spaces_to_fill = width - nchar(str)
-
-  rightsize = ceiling(spaces_to_fill / 2)
-  leftsize = spaces_to_fill - rightsize
-
-  rightfill = paste0(rep(fillchar, rightsize), collapse="")
-  leftfill = paste0(rep(fillchar, leftsize), collapse="")
-
-  return(paste0(leftfill, str, rightfill))
+  return(pystr_center_(str, width, fillchar))
 }
