@@ -2,10 +2,12 @@
 #'
 #' Like \code{\link{pystr_find}} but raises an error if \code{sub} is not found.
 #'
-#' @param str A string.
-#' @param sub A string.
+#' @param str A character vector.
+#' @param sub A character vector.
+#' @param start A numeric vector.
+#' @param end A numeric vector.
 #'
-#' @return An integer.
+#' @return A numeric vector.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.index}
 #'
@@ -13,13 +15,18 @@
 #'
 #' @examples
 #' pystr_index("abcxyzabc", "abc")
+#' pystr_index("abcxyzabc", "abc", 4)
 #' \dontrun{
 #' pystr_index("abcxyzabc", "123")
 #' }
 #'
 #' @export
-pystr_index <- function(str, sub) {
-  idx = pystr_find(str, sub)
+pystr_index <- function(str, sub, start=1, end=nchar(str)) {
+  return(mapply(pystr_index_, str, sub, start, end, USE.NAMES=FALSE))
+}
+
+pystr_index_ <- function(str, sub, start, end) {
+  idx = pystr_find(str, sub, start, end)
 
   if(idx < 0) {
     stop("ValueError")
