@@ -3,9 +3,9 @@
 #' Return \code{TRUE} if there are only whitespace characters in the string and there is at least
 #' one character, \code{FALSE} otherwise.
 #'
-#' @param str A string.
+#' @param str A character vector.
 #'
-#' @return \code{TRUE} or \code{FALSE}
+#' @return A logical vector.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.isspace}
 #'
@@ -15,6 +15,10 @@
 #'
 #' @export
 pystr_isspace <- function(str) {
+  return(vapply(str, function(x) pystr_isspace_(x), logical(1), USE.NAMES = FALSE))
+}
+
+pystr_isspace_ <- function(str) {
   if(nchar(str) == 0) {return(FALSE)}
 
   for(i in 1:nchar(str)) {
