@@ -1,14 +1,14 @@
 #' Partition a string.
 #'
-#' Split the string at the first occurrence of \code{sep}, and return a character vector containing the part
+#' Split the string at the first occurrence of \code{sep}, and return a list of character vectors containing the part
 #' before the separator, the separator itself, and the part after the separator.
 #'
 #' If the separator is not found, return a character vector containing the string itself, followed by two empty strings.
 #'
-#' @param str A string.
-#' @param sep A string.
+#' @param str A character vector.
+#' @param sep A character string.
 #'
-#' @return A character vector.
+#' @return A list of character vectors.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.partition}
 #'
@@ -19,6 +19,9 @@
 #'
 #' @export
 pystr_partition <- function(str, sep) {
+  return(mapply(pystr_partition_, str, sep, SIMPLIFY=FALSE, USE.NAMES=FALSE))
+}
+pystr_partition_ <- function(str, sep) {
   if(sep == "") {
     stop("Empty separator.")
   }
