@@ -3,12 +3,12 @@
 #' Return the higest index in the string where substring \code{sub} is found,
 #' such that \code{sub} is contained in the slice \code{substr(str, start, end)}.
 #'
-#' @param str A string.
-#' @param sub A string.
-#' @param start An integer.
-#' @param end An integer.
+#' @param str A character vector.
+#' @param sub A character vector.
+#' @param start A numeric vector.
+#' @param end A numeric vector.
 #'
-#' @return An integer. Returns \code{-1} if \code{sub} is not found.
+#' @return A numeric vector. \code{-1} indicates \code{sub} was not found.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.rfind}
 #'
@@ -21,6 +21,10 @@
 #'
 #' @export
 pystr_rfind <- function(str, sub, start=1, end=nchar(str)) {
+  return(mapply(pystr_rfind_, str, sub, start, end, USE.NAMES=FALSE))
+}
+
+pystr_rfind_ <- function(str, sub, start, end) {
   string_to_check = substr(str, start, end)
 
   for(i in nchar(string_to_check):1) {
