@@ -4,11 +4,11 @@
 #' Padding is done using the specified \code{fillchar} (default is an ASCII space).
 #' The original string is returned if \code{width} is less than or equal to \code{nchar(str)}.
 #'
-#' @param str A string.
+#' @param str A character vector.
 #' @param width An integer.
-#' @param fillchar A character.
+#' @param fillchar A character string.
 #'
-#' @return A string.
+#' @return A character vector.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.rjust}
 #'
@@ -20,6 +20,10 @@
 #'
 #' @export
 pystr_rjust <- function(str, width, fillchar=" ") {
+  return(vapply(str, function(x) pystr_rjust_(x, width, fillchar=fillchar), character(1), USE.NAMES = FALSE))
+}
+
+pystr_rjust_ <- function(str, width, fillchar) {
   if(width <= nchar(str)) {
     return(str)
   }
