@@ -1,12 +1,12 @@
 #' Partition a string from the right.
 #'
-#' Split the string at the last occurrence of \code{sep}, and return a character vector containing the part before the separator,
+#' Split the string at the last occurrence of \code{sep}, and return a list of character vectors containing the part before the separator,
 #' the separator itself, and the part after the separator.
 #'
 #' If the separator is not found, return a character vector containing two empty strings, followed by the string itself.
 #'
-#' @param str A string.
-#' @param sep A string.
+#' @param str A character vector.
+#' @param sep A character string.
 #'
 #' @return A character vector.
 #'
@@ -19,6 +19,10 @@
 #'
 #' @export
 pystr_rpartition <- function(str, sep) {
+  return(mapply(pystr_rpartition_, str, sep, SIMPLIFY=FALSE, USE.NAMES=FALSE))
+}
+
+pystr_rpartition_ <- function(str, sep) {
   if(sep == "") {
     stop("Empty separator.")
   }
