@@ -1,6 +1,6 @@
 #' Right split a string.
 #'
-#' Return a character vector of the words in the string, using \code{sep} as the delimiter
+#' Return a list of character vectors of the words in the string, using \code{sep} as the delimiter
 #' string.
 #'
 #' If \code{maxsplit} is given, at most \code{maxsplit} splits are done, the rightmost
@@ -8,11 +8,11 @@
 #' Except for splitting from the right, \code{pystr_rsplit} behaves like
 #' \code{\link{pystr_split}}.
 #'
-#' @param str A string.
-#' @param sep A string.
-#' @param maxsplit An integer.
+#' @param str A character vector.
+#' @param sep A character string.
+#' @param maxsplit A numeric vector.
 #'
-#' @return A character vector.
+#' @return A list of character vectors.
 #'
 #' @references \url{https://docs.python.org/3/library/stdtypes.html#str.rsplit}
 #'
@@ -23,7 +23,10 @@
 #' pystr_rsplit("a--b--c", "--", 1)
 #'
 #' @export
-pystr_rsplit <- function(str, sep = " ", maxsplit=nchar(str) - 1) {
+pystr_rsplit <- function(str, sep=" ", maxsplit=nchar(str)-1) {
+  return(mapply(pystr_rsplit_, str, sep, maxsplit, SIMPLIFY=FALSE, USE.NAMES=FALSE))
+}
+pystr_rsplit_ <- function(str, sep, maxsplit) {
   if(maxsplit == 0) {
     return(str)
   }
@@ -47,7 +50,7 @@ pystr_rsplit <- function(str, sep = " ", maxsplit=nchar(str) - 1) {
 
   while(cum_splits < num_splits) {
     if(remaining == "") {return(elements)}
-    parts = pystr_rpartition(remaining, sep)
+    parts = pystr_rpartition(remaining, sep)[[1]]
     elements = c(elements, parts[3])
     remaining = parts[1]
     cum_splits = cum_splits + 1
