@@ -9,22 +9,6 @@ test_that("it works with a string suffix that's not present", {
   expect_false(pystr_endswith("selfie.jpg", ".png"))
 })
 
-test_that("it works with a list of suffixes where one is present", {
-  expect_true(pystr_endswith("selfie.jpg", list(".jpg", ".png")))
-})
-
-test_that("it works with a list of suffixes where none are present", {
-  expect_false(pystr_endswith("selfie.jpg", list(".gif", ".png")))
-})
-
-test_that("it works with a vector of suffixes where one is present", {
-  expect_true(pystr_endswith("selfie.jpg", c(".jpg", ".png")))
-})
-
-test_that("it works with a vector of suffixes where none are present", {
-  expect_false(pystr_endswith("selfie.jpg", c(".gif", ".png")))
-})
-
 test_that("it works with a start and end range", {
   expect_true(pystr_endswith("hello world", "ello", 1, 5))
 })
@@ -36,3 +20,11 @@ test_that("it returns FALSE when start and end are out of bounds", {
 test_that("all strings end with an empty string", {
   expect_true(pystr_endswith("hello", ""))
 })
+
+test_that("it works with a character vector", {
+ expect_equal(pystr_endswith(c("selfie.jpg", "selfie.png"), ".jpg"), c(TRUE, FALSE))
+})
+
+test_that("it works with multiple character vectors", {
+  expect_equal(pystr_endswith(c("selfie.jpg", "selfie.png"), c(".jpg", ".png")), c(TRUE, TRUE))
+})
