@@ -16,3 +16,11 @@ test_that("the presence of punctuation and numerics doesn't matter", {
 test_that("it returns false if there are no cased characters", {
   expect_false(pystr_islower("?!."))
 })
+
+test_that("it handles vectors", {
+  expect_equal(pystr_islower(c("?!.", "abc")), c(FALSE, TRUE))
+})
+
+test_that("it handles NAs", {
+  expect_equal(pystr_islower(c("?!.", "abc", NA)), c(FALSE, TRUE, NA))
+})
