@@ -24,3 +24,11 @@ test_that("it can replace empty strings with a count", {
 test_that("if count is 0, return the string itself", {
   expect_equal(pystr_replace("ABCD", "CD", "X", 0), "ABCD")
 })
+
+test_that("it works with a character vector", {
+  expect_equal(pystr_replace(c("ABC", "BC"), "B", "X"), c("AXC", "XC"))
+})
+
+test_that("it works with multiple character vectors", {
+  expect_equal(pystr_replace(c("ABC", "BC"), c("B", "C"), c("X", "Y")), c("AXC", "BY"))
+})
