@@ -16,3 +16,11 @@ test_that("it returns -1 when the substring isn't there", {
 test_that("it finds the index when start and end both truncate", {
   expect_equal(pystr_rfind("abcxyzabc", "xyz", 4, 7), 4)
 })
+
+test_that("it works with a character vector", {
+  expect_equal(pystr_rfind(c("123123", "123"), "123"), c(4, 1))
+})
+
+test_that("it works with multiple character vectors", {
+  expect_equal(pystr_rfind(c("123123", "12345"), c("123", "45")), c(4, 4))
+})
