@@ -8,3 +8,7 @@ test_that("it strips spaces by default", {
 test_that("it strips characters until it encounters one that isn't in chars", {
   expect_equal(pystr_rstrip("mississippi", "ipz"), "mississ")
 })
+
+test_that("it works with a character vector", {
+  expect_equal(pystr_rstrip(c("  spacious  ", "  hi  ")), c("  spacious", "  hi"))
+})
